ChangeLog
=========

.. note::
    This changelog contains only a summary of changes. For a more accurate
    accounting of development history please inspect the source history
    directly.

CheckBoxNG 0.3
--------------

* Bugfixes: https://launchpad.net/checkbox-ng/+milestone/0.3

CheckBoxNG 0.2
--------------

???

CheckBoxNG 0.1
--------------

* Initial release
* Support for displaying configuration
* Support for running SRU tests (automatic regression testing)
